authoringfw — UI Demo

## ChapterTask

Chapter Title *
Chapter Outline (Beat Sheet) * Protagonist betritt die Stadt. Trifft eine mysteriöse Frau. Sie deutet auf ein Geheimnis hin. Held zieht weiter, verunsichert.
Previous Chapter Summary In Kapitel 1 verließ der Held sein Dorf und begab sich auf die Reise.
Style Notes
Target Word Count
Quality Level (1-9)
Priority
World Context

## Generated Messages

## SummaryTask

Source Text * Die Stadt lag im Morgendunst, als der Held durch das Tor schritt. Er hatte viele Wochen gereist und seine Stiefel erzählten von den Wegen, die er zurückgelegt hatte. Eine Frau im roten Umhang beobachtete ihn vom Marktstand aus...
Style
Max Words

## Generated Messages

## ResearchTask

Topic *
Context (optional)
Output Format
Max Words

## Generated Messages

## AnalysisTask

Analyser
Source Text * Die Stadt lag im Morgendunst. Der Held schritt durch das Tor, müde und voller Hoffnung zugleich. Er hatte keine Ahnung, was ihn erwartete, aber er wusste, dass es kein Zurück mehr gab.
Analysis Focus
Output Format

## Generated Messages

## Research → Writing Pipeline (ADR-096 §4.5)

1 ResearchOrchestrator
2 ChapterOrchestrator
Held geht durch nebeliges London. Sieht verdächtige Gestalt. Folgt ihr in dunkle Gasse.
3 SummaryOrchestrator

Auto-runs after chapter to generate previous_summary for next chapter.